SystemOrganization addCategory: #GODTextIOTests!

TestCase subclass: #TXTIOConverterTest
	instanceVariableNames: 'testDir textIO'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODTextIOTests'!

!TXTIOConverterTest commentStamp: 'jlcg 9/27/2014 12:02' prior: 0!
SUnit tests to TXTInterface class.!

!TXTIOConverterTest class methodsFor: 'history' stamp: 'jlcg 11/21/2014 17:00'!
lastStoredRun
	^ ((Dictionary new) add: (#failures->((Set new) add: #testReadOdtFromFileReturn; yourself)); add: (#errors->((Set new) add: #testWriteTextToFileOverwrite; add: #testReadTextFromFileReturn; add: #testWritePdfToFileOverwrite; add: #testWriteOdtToFileAppend; add: #testWriteTextToFileAppend; yourself)); add: (#passed->((Set new) add: #testWriteRtfToFileBasic; add: #testWritePdfToExistentFileOverwrite; add: #testWriteOdtToExistentFileOverwrite; add: #testWriteOdtToFileBasic; add: #testWriteRtfToFileOverwrite; add: #testWriteOdtToFileOverwrite; add: #testWriteRtfToExistentFileOverwrite; add: #testReadFromInexistentFile; add: #testWriteTextToExistentFileOverwrite; add: #testWriteTextToNonexistentFileAppend; add: #testWriteTextToFileBasic; add: #testWritePdfToFileBasic; add: #testWriteOdtToNonexistentFileAppend; yourself)); add: (#timeStamp->'21 November 2014 5:00:16 pm' asTimeStamp); yourself)! !

!TXTIOConverterTest methodsFor: 'initialize-release' stamp: 'jlcg 11/20/2014 15:47'!
setUp
	textIO := TXTIOConverter new.

	testDir := FileDirectory default / '_test_textio'.
	testDir assureExistence.! !

!TXTIOConverterTest methodsFor: 'tests' stamp: 'jlcg 11/21/2014 16:51'!
testReadFromInexistentFile
	"Tests if trying to read contents from an inexistent file throws an exception."

	self should: [ textIO readFromFile: testDir pathName, FileDirectory slash, 'this_file_must_not_exist.txt' ] raise: GODTextIOFileDoesNotExist.
	self should: [ textIO readFromFile: testDir pathName, FileDirectory slash, 'this_file_must_not_exist.txt' type: 'txt' ] raise: GODTextIOFileDoesNotExist.! !

!TXTIOConverterTest methodsFor: 'tests' stamp: 'jlcg 12/2/2014 11:21'!
testReadOdtFromFileReturn
	"Tests if the return of readFromFile methods is a GODData object, and checks its contents, for ODT files."

	| fileName godData |

	fileName := testDir pathName, FileDirectory slash, DateAndTime now asNanoSeconds, '_read.odt'.

	godData := GODData new.
	godData author: 'Author'.
	godData content: 'Test'.
	godData origin: 'TextIO'.
	godData timestamp: 'Date'.
	godData title: 'Title'.

	textIO write: godData toFile: fileName.
	self assert: ( FileDirectory new fileExists: fileName ).

	godData := textIO readFromFile: fileName.
	self assert: ( godData isGODData ).
	self assert: ( godData content = ( 'Title', Character cr, 'Author', Character cr, 'Date', Character cr, Character cr, 'Test' ) ).

	godData := textIO readFromFile: fileName type: 'odt'.
	self assert: ( godData isGODData ).
	self assert: ( godData content = ( 'Title', Character cr, 'Author', Character cr, 'Date', Character cr, Character cr, 'Test' ) ).! !

!TXTIOConverterTest methodsFor: 'tests' stamp: 'jlcg 12/2/2014 11:22'!
testReadPdfFromFileReturn
	"Tests if the return of readFromFile methods is a GODData object, and checks its contents, for PDF files."

	| fileName godData |

	fileName := testDir pathName, FileDirectory slash, DateAndTime now asNanoSeconds, '_read.pdf'.

	godData := GODData new.
	godData author: 'Author'.
	godData content: 'Test'.
	godData origin: 'TextIO'.
	godData timestamp: 'Date'.
	godData title: 'Title'.

	textIO write: godData toFile: fileName.
	self assert: ( FileDirectory new fileExists: fileName ).

	godData := textIO readFromFile: fileName.
	self assert: ( godData isGODData ).
	self assert: ( godData content = ( 'Title', Character cr, 'Author', Character cr, 'Date', Character cr, 'Test', Character cr, Character cr, '1', Character cr, Character cr ) ).

	godData := textIO readFromFile: fileName type: 'pdf'.
	self assert: ( godData isGODData ).
	self assert: ( godData content = ( 'Title', Character cr, 'Author', Character cr, 'Date', Character cr, 'Test', Character cr, Character cr, '1', Character cr, Character cr ) ).! !

!TXTIOConverterTest methodsFor: 'tests' stamp: 'jlcg 12/2/2014 11:19'!
testReadRtfFromFileReturn
	"Tests if the return of readFromFile methods is a GODData object, and checks its contents, for RTF files."

	| fileName godData |

	fileName := testDir pathName, FileDirectory slash, DateAndTime now asNanoSeconds, '_read.rtf'.

	godData := GODData new.
	godData author: 'Author'.
	godData content: 'Test'.
	godData origin: 'TextIO'.
	godData timestamp: 'Date'.
	godData title: 'Title'.

	textIO write: godData toFile: fileName.
	self assert: ( FileDirectory new fileExists: fileName ).

	godData := textIO readFromFile: fileName.
	self assert: ( godData isGODData ).
	self assert: ( godData content = ( 'Title', Character cr, 'Author', Character cr, 'Date', Character cr, Character cr, 'Test' ) ).

	godData := textIO readFromFile: fileName type: 'rtf'.
	self assert: ( godData isGODData ).
	self assert: ( godData content = ( 'Title', Character cr, 'Author', Character cr, 'Date', Character cr, Character cr, 'Test' ) ).! !

!TXTIOConverterTest methodsFor: 'tests' stamp: 'jlcg 11/21/2014 17:37'!
testReadTextFromFileReturn
	"Tests if the return of readFromFile methods is a GODData object, and checks its contents, for TXT files."

	| fileName godData |

	fileName := testDir pathName, FileDirectory slash, DateAndTime now asNanoSeconds, '_read.txt'.

	godData := GODData new.
	godData content: 'teste'.

	textIO write: godData toFile: fileName.
	self assert: ( FileDirectory new fileExists: fileName ).

	godData := textIO readFromFile: fileName.
	self assert: ( godData isGODData ).
	self assert: ( godData content = 'teste' ).

	godData := textIO readFromFile: fileName type: 'txt'.
	self assert: ( godData isGODData ).
	self assert: ( godData content = 'teste' ).! !

!TXTIOConverterTest methodsFor: 'tests' stamp: 'jlcg 11/21/2014 17:19'!
testWriteOdtToExistentFileOverwrite
	"Tests whether trying to write contents to an existent file with 'overwrite' option set to False throws an exception"

	| fileName godData |

	fileName := testDir pathName, FileDirectory slash, DateAndTime now asNanoSeconds, '_eo.odt'.

	godData := GODData new.
	godData author: 'TextIO Group'.
	godData content: 'Test from Text Converting Module - Overwrite on ODT'.
	godData origin: 'TextIO'.
	godData timestamp: TimeStamp now asString.
	godData title: 'Test from TextIO Group'.

	textIO write: godData toFile: fileName type: 'odt'.
	self assert: ( FileDirectory new fileExists: fileName ).

	self should: [ textIO write: godData toFile: fileName type: 'odt' overwrite: false ] raise: GODTextIOFileAlreadyExists.! !

!TXTIOConverterTest methodsFor: 'tests' stamp: 'jlcg 11/21/2014 17:19'!
testWriteOdtToFileAppend
	"Tests the appending operation to an existent file"

	| fileName godData |

	fileName := testDir pathName, FileDirectory slash, DateAndTime now asNanoSeconds, '_app.odt'.

	godData := GODData new.
	godData author: 'TextIO Group'.
	godData content: 'Test from Text Processing module - Write ODT'.
	godData origin: 'TextIO'.
	godData timestamp: TimeStamp now asString.
	godData title: 'Test from TextIO Group'.

	textIO write: godData toFile: fileName type: 'odt'.
	self assert: ( FileDirectory new fileExists: fileName ).

	godData content: 'Test from Text Processing module - Appending data'.
	self assert: ( textIO write: godData toFile: fileName type: 'odt' append: true ).! !

!TXTIOConverterTest methodsFor: 'tests' stamp: 'jlcg 11/21/2014 17:20'!
testWriteOdtToFileBasic
	"Tests write: toFile: method, and its variants"

	| filePrefix godData |

	godData := GODData new.
	godData author: 'TextIO Group'.
	godData content: 'Test from Text Processing module - Write Basic ODT'.
	godData origin: 'TextIO'.
	godData timestamp: TimeStamp now asString.
	godData title: 'Test from TextIO Group'.

	filePrefix := testDir pathName, FileDirectory slash, ( DateAndTime now asNanoSeconds ) asString, '_basic_odt'.

	self assert: ( textIO write: godData toFile: filePrefix, '_1.odt' ).
	self assert: ( textIO write: godData toFile: filePrefix, '_2.odt' type: 'odt' ).
	self assert: ( textIO write: godData toFile: filePrefix, '_3.odt' type: 'odt' append: false ).
	self assert: ( textIO write: godData toFile: filePrefix, '_4.odt' type: 'odt' overwrite: false ).

	self assert: ( FileDirectory new fileExists: filePrefix, '_1.odt' ).
	self assert: ( FileDirectory new fileExists: filePrefix, '_2.odt' ).
	self assert: ( FileDirectory new fileExists: filePrefix, '_3.odt' ).
	self assert: ( FileDirectory new fileExists: filePrefix, '_4.odt' ).! !

!TXTIOConverterTest methodsFor: 'tests' stamp: 'jlcg 11/21/2014 17:26'!
testWriteOdtToFileOverwrite
	"Tests overwriting operation on an existent file"

	| fileName godData |

	fileName := testDir pathName, FileDirectory slash, DateAndTime now asNanoSeconds, '_over.odt'.

	godData := GODData new.
	godData author: 'TextIO Group'.
	godData content: 'Test from Text Processing module - Write Overwrite ODT'.
	godData origin: 'TextIO'.
	godData timestamp: TimeStamp now asString.
	godData title: 'Test from TextIO Group'.

	textIO write: godData toFile: fileName type: 'odt'.
	self assert: ( FileDirectory new fileExists: fileName ).

	godData content: 'Test from Text Processing module - Overwrite content ODT'.
	self assert: ( textIO write: godData toFile: fileName type: 'odt' overwrite: true ).! !

!TXTIOConverterTest methodsFor: 'tests' stamp: 'jlcg 11/21/2014 16:49'!
testWriteOdtToNonexistentFileAppend
	"Tests whether trying to append contents to a nonexistent file throws an exception"

	| godData |

	godData := GODData new.

	self should: [ textIO write: godData toFile: '/tmp/test_append_nonexistent.odt' type: 'odt' append: true ] raise: GODTextIOFileDoesNotExist.! !

!TXTIOConverterTest methodsFor: 'tests' stamp: 'jlcg 11/21/2014 17:22'!
testWritePdfToExistentFileOverwrite
	"Tests whether trying to write contents to an existent file with 'overwrite' option set to False throws an exception"

	| fileName godData |

	fileName := testDir pathName, FileDirectory slash, DateAndTime now asNanoSeconds, '_eo.pdf'.

	godData := GODData new.
	godData author: 'TextIO Group'.
	godData content: 'Test from Text Processing module - Write Overwrite PDF'.
	godData origin: 'TextIO'.
	godData timestamp: TimeStamp now asString.
	godData title: 'Test from TextIO Group'.

	textIO write: godData toFile: fileName type: 'pdf'.
	self assert: ( FileDirectory new fileExists: fileName ).

	self should: [ textIO write: godData toFile: fileName type: 'pdf' overwrite: false ] raise: GODTextIOFileAlreadyExists.! !

!TXTIOConverterTest methodsFor: 'tests' stamp: 'jlcg 11/21/2014 17:20'!
testWritePdfToFileBasic
	"Tests write: toFile: method, and its variants"

	| filePrefix godData |

	godData := GODData new.
	godData author: 'TextIO Group'.
	godData content: 'Test from Text Processing module - Write Basic PDF'.
	godData origin: 'TextIO'.
	godData timestamp: TimeStamp now asString.
	godData title: 'Test from TextIO Group'.

	filePrefix := ( testDir pathName, FileDirectory slash, DateAndTime now asNanoSeconds ) asString, '_basic_pdf'.

	self assert: ( textIO write: godData toFile: filePrefix, '_1.pdf' ).
	self assert: ( textIO write: godData toFile: filePrefix, '_2.pdf' type: 'pdf' ).
	self assert: ( textIO write: godData toFile: filePrefix, '_3.pdf' type: 'pdf' append: false ).
	self assert: ( textIO write: godData toFile: filePrefix, '_4.pdf' type: 'pdf' overwrite: false ).

	self assert: ( FileDirectory new fileExists: filePrefix, '_1.pdf' ).
	self assert: ( FileDirectory new fileExists: filePrefix, '_2.pdf' ).
	self assert: ( FileDirectory new fileExists: filePrefix, '_3.pdf' ).
	self assert: ( FileDirectory new fileExists: filePrefix, '_4.pdf' ).! !

!TXTIOConverterTest methodsFor: 'tests' stamp: 'jlcg 11/21/2014 17:26'!
testWritePdfToFileOverwrite
	"Tests overwriting operation on an existent file"

	| fileName godData |

	fileName := testDir pathName, FileDirectory slash, DateAndTime now asNanoSeconds, '_over.pdf'.

	godData := GODData new.
	godData author: 'TextIO Group'.
	godData content: 'Test from Text Processing module - Write Overwrite PDF'.
	godData origin: 'TextIO'.
	godData timestamp: TimeStamp now asString.
	godData title: 'Test from TextIO Group'.

	textIO write: godData toFile: fileName type: 'pdf'.
	self assert: ( FileDirectory new fileExists: fileName ).

	godData content: 'Test from Text Processing module - Overwrite content PDF'.
	self assert: ( textIO write: godData toFile: fileName type: 'pdf' overwrite: true ).! !

!TXTIOConverterTest methodsFor: 'tests' stamp: 'jlcg 11/21/2014 17:22'!
testWriteRtfToExistentFileOverwrite
	"Tests whether trying to write contents to an existent file with 'overwrite' option set to False throws an exception"

	| fileName godData |

	fileName := testDir pathName, FileDirectory slash, DateAndTime now asNanoSeconds, '_eo.rtf'.

	godData := GODData new.
	godData author: 'TextIO Group'.
	godData content: 'Test from Text Processing module - Write Overwrite RTF'.
	godData origin: 'TextIO'.
	godData timestamp: TimeStamp now asString.
	godData title: 'Test from TextIO Group'.

	textIO write: godData toFile: fileName type: 'rtf'.
	self assert: ( FileDirectory new fileExists: fileName ).

	self should: [ textIO write: godData toFile: fileName type: 'rtf' overwrite: false ] raise: GODTextIOFileAlreadyExists.! !

!TXTIOConverterTest methodsFor: 'tests' stamp: 'jlcg 11/21/2014 17:20'!
testWriteRtfToFileBasic
	"Tests write: toFile: method, and its variants"

	| filePrefix godData |

	godData := GODData new.
	godData author: 'TextIO Group'.
	godData content: 'Test from Text Processing module - Write Basic RTF'.
	godData origin: 'TextIO'.
	godData timestamp: TimeStamp now asString.
	godData title: 'Test from TextIO Group'.

	filePrefix := ( testDir pathName, FileDirectory slash, DateAndTime now asNanoSeconds ) asString, '_basic_rtf'.

	self assert: ( textIO write: godData toFile: filePrefix, '_1.rtf' ).
	self assert: ( textIO write: godData toFile: filePrefix, '_2.rtf' type: 'rtf' ).
	self assert: ( textIO write: godData toFile: filePrefix, '_3.rtf' type: 'rtf' append: false ).
	self assert: ( textIO write: godData toFile: filePrefix, '_4.rtf' type: 'rtf' overwrite: false ).

	self assert: ( FileDirectory new fileExists: filePrefix, '_1.rtf' ).
	self assert: ( FileDirectory new fileExists: filePrefix, '_2.rtf' ).
	self assert: ( FileDirectory new fileExists: filePrefix, '_3.rtf' ).
	self assert: ( FileDirectory new fileExists: filePrefix, '_4.rtf' ).! !

!TXTIOConverterTest methodsFor: 'tests' stamp: 'jlcg 11/21/2014 17:26'!
testWriteRtfToFileOverwrite
	"Tests overwriting operation on an existent file"

	| fileName godData |

	fileName := testDir pathName, FileDirectory slash, DateAndTime now asNanoSeconds, '_over.rtf'.

	godData := GODData new.
	godData author: 'TextIO Group'.
	godData content: 'Test from RTF Processing module - Write Overwrite RTF'.
	godData origin: 'TextIO'.
	godData timestamp: TimeStamp now asString.
	godData title: 'Test from TextIO Group'.

	textIO write: godData toFile: fileName type: 'rtf'.
	self assert: ( FileDirectory new fileExists: fileName ).

	godData content: 'Test from RTF Processing module - Overwrite content RTF'.
	self assert: ( textIO write: godData toFile: fileName type: 'rtf' overwrite: true ).! !

!TXTIOConverterTest methodsFor: 'tests' stamp: 'jlcg 11/21/2014 17:24'!
testWriteTextToExistentFileOverwrite
	"Tests whether trying to write contents to an existent file with 'overwrite' option set to False throws an exception"

	| fileName godData |

	fileName := testDir pathName, FileDirectory slash, DateAndTime now asNanoSeconds, '_eo.txt'.

	godData := GODData new.
	godData origin: 'TextIO'.
	godData content: 'Test from Text Processing module - Write Overwrite TXT'.

	textIO write: godData toFile: fileName type: 'txt'.
	self assert: ( FileDirectory new fileExists: fileName ).

	self should: [ textIO write: godData toFile: fileName type: 'txt' overwrite: false ] raise: GODTextIOFileAlreadyExists.! !

!TXTIOConverterTest methodsFor: 'tests' stamp: 'jlcg 11/21/2014 17:20'!
testWriteTextToFileAppend
	"Tests the appending operation to an existent file"

	| fileName godData |

	fileName := testDir pathName, FileDirectory slash, DateAndTime now asNanoSeconds, '_app.txt'.

	godData := GODData new.
	godData origin: 'TextIO'.
	godData content: 'Test from Text Processing module - Write Append'.

	textIO write: godData toFile: fileName type: 'txt'.
	self assert: ( FileDirectory new fileExists: fileName ).

	godData content: 'Test from Text Processing module - Appending data'.
	self assert: ( textIO write: godData toFile: fileName type: 'txt' append: true ).! !

!TXTIOConverterTest methodsFor: 'tests' stamp: 'jlcg 11/21/2014 17:20'!
testWriteTextToFileBasic
	"Tests write: toFile: method, and its variants"

	| filePrefix godData |

	godData := GODData new.
	godData origin: 'TextIO'.
	godData content: 'Test from Text Processing module'.	

	filePrefix := ( testDir pathName, FileDirectory slash, DateAndTime now asNanoSeconds ) asString, '_basic_txt'.

	self assert: ( textIO write: godData toFile: filePrefix, '_1.txt' ).
	self assert: ( textIO write: godData toFile: filePrefix, '_2.txt' type: 'txt' ).
	self assert: ( textIO write: godData toFile: filePrefix, '_3.txt' type: 'txt' append: false ).
	self assert: ( textIO write: godData toFile: filePrefix, '_4.txt' type: 'txt' overwrite: false ).

	self assert: ( FileDirectory new fileExists: filePrefix, '_1.txt' ).
	self assert: ( FileDirectory new fileExists: filePrefix, '_2.txt' ).
	self assert: ( FileDirectory new fileExists: filePrefix, '_3.txt' ).
	self assert: ( FileDirectory new fileExists: filePrefix, '_4.txt' ).! !

!TXTIOConverterTest methodsFor: 'tests' stamp: 'jlcg 11/21/2014 17:26'!
testWriteTextToFileOverwrite
	"Tests overwriting operation on an existent file"

	| fileName godData |

	fileName := testDir pathName, FileDirectory slash, DateAndTime now asNanoSeconds, '_over.txt'.

	godData := GODData new.
	godData origin: 'TextIO'.
	godData content: 'Test from Text Processing module - Write Overwrite TXT'.

	textIO write: godData toFile: fileName type: 'txt'.
	self assert: ( FileDirectory new fileExists: fileName ).

	godData content: 'Test from Text Processing module - Overwrite content TXT'.
	self assert: ( textIO write: godData toFile: fileName type: 'txt' overwrite: true ).! !

!TXTIOConverterTest methodsFor: 'tests' stamp: 'jlcg 10/31/2014 17:35'!
testWriteTextToNonexistentFileAppend
	"Tests whether trying to append contents to a nonexistent file throws an exception"

	| godData |

	godData := GODData new.

	self should: [ textIO write: godData toFile: '/tmp/test_append_nonexistent.txt' type: 'txt' append: true ] raise: GODTextIOFileDoesNotExist.! !
